==> hubzero-submit-monitors_2.5.1.orig.tar.gz: hubzero-submit-monitors-2.5.1/monitorJobInitialize.sh <==
#!/bin/sh
#
# @package      hubzero-submit-monitors
# @file         monitorJobInitialize.sh
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2004-2013 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#
# ----------------------------------------------------------------------
#  monitorJobInitialize.sh
#
#  script which controls initialization job monitoring statistics files
#
# Become root if not already.
#
if [ $(id -u) -ne 0 ] ; then
   sudo $0
   exit $?
fi

currentDirectory=${PWD}

/etc/init.d/jobmon stop

cd /opt/submit/DB
rm -f monitorJob.db
python ../monitorJobInitialize.py 
chown gridman:apps monitorJob.db
chmod 0640 monitorJob.db

rm -f monitorJob.sql
touch monitorJob.sql
chown gridman:apps monitorJob.sql
chmod 0640 monitorJob.sql

sleep 30

cd ${currentDirectory}

/etc/init.d/jobmon start

==> hubzero-submit-monitors_2.5.7.orig.tar.gz: hubzero-submit-monitors-2.5.7/monitorJobInitialize.sh <==
#!/bin/sh
#
# @package      hubzero-submit-monitors
# @file         monitorJobInitialize.sh
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#
# ----------------------------------------------------------------------
#  monitorJobInitialize.sh
#
#  script which controls initialization job monitoring statistics files
#
# Become root if not already.
#
if [ $(id -u) -ne 0 ] ; then
   sudo $0
   exit $?
fi

currentDirectory=${PWD}

/etc/init.d/jobmon stop

mkdir -p /opt/submit/DB
cd /opt/submit/DB
rm -f monitorJob.db
python ../monitorJobInitialize.py 
chown gridman:root monitorJob.db
chmod 0640 monitorJob.db

rm -f monitorJob.sql
touch monitorJob.sql
chown gridman:root monitorJob.sql
chmod 0640 monitorJob.sql

sleep 30

cd ${currentDirectory}

/etc/init.d/jobmon start
